@@ -1,4 +1,3 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for mediastore-data service client
 
@@ -14,7 +13,6 @@ Usage::
 import sys
 from typing import IO, Any, Dict, Type, Union
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_mediastore_data.paginator import ListItemsPaginator
@@ -34,6 +32,14 @@ else:
 __all__ = ("MediaStoreDataClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     ContainerNotFoundException: Type[BotocoreClientError]
@@ -44,7 +50,7 @@ class Exceptions:
 
 class MediaStoreDataClient:
     """
-    [MediaStoreData.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client)
+    [MediaStoreData.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client)
     """
 
     meta: ClientMeta
@@ -52,17 +58,17 @@ class MediaStoreDataClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.can_paginate)
         """
 
     def delete_object(self, Path: str) -> Dict[str, Any]:
         """
-        [Client.delete_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.delete_object)
+        [Client.delete_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.delete_object)
         """
 
     def describe_object(self, Path: str) -> DescribeObjectResponseTypeDef:
         """
-        [Client.describe_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.describe_object)
+        [Client.describe_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.describe_object)
         """
 
     def generate_presigned_url(
@@ -73,19 +79,19 @@ class MediaStoreDataClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.generate_presigned_url)
         """
 
     def get_object(self, Path: str, Range: str = None) -> GetObjectResponseTypeDef:
         """
-        [Client.get_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.get_object)
+        [Client.get_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.get_object)
         """
 
     def list_items(
         self, Path: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListItemsResponseTypeDef:
         """
-        [Client.list_items documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.list_items)
+        [Client.list_items documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.list_items)
         """
 
     def put_object(
@@ -98,10 +104,10 @@ class MediaStoreDataClient:
         UploadAvailability: Literal["STANDARD", "STREAMING"] = None,
     ) -> PutObjectResponseTypeDef:
         """
-        [Client.put_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Client.put_object)
+        [Client.put_object documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Client.put_object)
         """
 
     def get_paginator(self, operation_name: Literal["list_items"]) -> ListItemsPaginator:
         """
-        [Paginator.ListItems documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Paginator.ListItems)
+        [Paginator.ListItems documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/mediastore-data.html#MediaStoreData.Paginator.ListItems)
         """
